==> haskell-gtk-strut-0.1.3.2-338.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-strut.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gtk-strut
version:              0.1.3.2
visibility:           public
id:                   gtk-strut-0.1.3.2-3PGGCnyfUvj1A6worT036H
key:                  gtk-strut-0.1.3.2-3PGGCnyfUvj1A6worT036H
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-strut#readme
synopsis:             Library for creating strut windows with gi-gtk
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-strut#readme>

category:             System
abi:                  04faf5415d601b4c14943b9897892e97
exposed:              True
exposed-modules:      Graphics.UI.GIGtkStrut
hidden-modules:       Graphics.UI.EWMHStrut
import-dirs:          /usr/lib/ghc-9.6.6/site-local/gtk-strut-0.1.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gtk-strut-0.1.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gtk-strut-0.1.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-strut
hs-libraries:         HSgtk-strut-0.1.3.2-3PGGCnyfUvj1A6worT036H
depends:
    base-4.18.2.1 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    gi-gdk-3.0.29-Gzlw5EloE4R1j7cn52vC9T
    gi-gtk-3.0.43-8dFbmSwa2Ur2f6lKdY0m8q
    hslogger-1.3.2.0-H4OZ1FZbeeNMbSjFBgOfV text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-gtk-strut/html/gtk-strut.haddock
haddock-html:         /usr/share/doc/haskell-gtk-strut/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk-strut-0.1.3.2-340-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-strut.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gtk-strut
version:              0.1.3.2
visibility:           public
id:                   gtk-strut-0.1.3.2-RPNTLEvW9s5PbEBrvbgC8
key:                  gtk-strut-0.1.3.2-RPNTLEvW9s5PbEBrvbgC8
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-strut#readme
synopsis:             Library for creating strut windows with gi-gtk
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-strut#readme>

category:             System
abi:                  2a0b59cff220c348a91151e66124b48e
exposed:              True
exposed-modules:      Graphics.UI.GIGtkStrut
hidden-modules:       Graphics.UI.EWMHStrut
import-dirs:          /usr/lib/ghc-9.6.6/site-local/gtk-strut-0.1.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gtk-strut-0.1.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gtk-strut-0.1.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-strut
hs-libraries:         HSgtk-strut-0.1.3.2-RPNTLEvW9s5PbEBrvbgC8
depends:
    base-4.18.2.1 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    gi-gdk-3.0.29-IjqrlTmXxDIKTyIOtnIEV
    gi-gtk-3.0.43-2YGdBsPsy8b6gP805A8iv8
    hslogger-1.3.2.0-H4OZ1FZbeeNMbSjFBgOfV text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-gtk-strut/html/gtk-strut.haddock
haddock-html:         /usr/share/doc/haskell-gtk-strut/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
